darkhistory.spec.transferfunclist.TransferFuncInterps
=====================================================

.. currentmodule:: darkhistory.spec.transferfunclist

.. autoclass:: TransferFuncInterps

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TransferFuncInterps.__init__
      ~TransferFuncInterps.get_tf
   
   

   
   
   